@@ -19,7 +19,7 @@ from my.core import Paths, PathIsh
 class hypothesis:
     # expects outputs from https://github.com/karlicoss/hypexport
     # (it's just the standard Hypothes.is export format)
-    export_path: Paths = '/path/to/hypothesis/data'
+    export_path: Paths = r'/path/to/hypothesis/data'
 
 class instapaper:
     export_path: Paths = ''
@@ -72,10 +72,20 @@ class location:
     # and we can't import the types from the module itself, otherwise would be circular. common module?
     home: Union[LatLon, Sequence[Tuple[DateIsh, LatLon]]] = (1.0, -1.0)
 
+    class via_ip:
+        accuracy: float
+
+    class gpslogger:
+        export_path: Paths = ''
+        accuracy: float
+
 
 class time:
     class tz:
-        pass
+        class via_location:
+            fast: bool
+            sort_locations: bool
+            require_accuracy: float
 
 
 class orgmode:
