@@ -4,8 +4,7 @@ Bindings for the 'core' HPI configuration
 import re
 from typing import Sequence, Optional
 
-from .common import PathIsh
-from . import warnings
+from . import warnings, PathIsh, Path
 
 try:
     from my.config import core as user_config # type: ignore[attr-defined]
@@ -20,22 +19,71 @@ except Exception as e:
         user_config = object # type: ignore[assignment, misc]
 
 
+_HPI_CACHE_DIR_DEFAULT = ''
+
 from dataclasses import dataclass
 @dataclass
 class Config(user_config):
-    # TODO if attr is set _and_ it's none, disable cache?
-    # todo or empty string?
-    # I guess flip the switch at some point when I'm confident in cachew
-    cache_dir: Optional[PathIsh] = None # FIXME use appdirs cache dir or something
+    '''
+    Config for the HPI itself.
+    To override, add to your config file something like
+
+    class config:
+        cache_dir = '/your/custom/cache/path'
+    '''
+
+    cache_dir: Optional[PathIsh] = _HPI_CACHE_DIR_DEFAULT
+    '''
+    Base directory for cachew.
+    - if None             , means cache is disabled
+    - if '' (empty string), use user cache dir (see https://github.com/ActiveState/appdirs for more info). This is the default.
+    - otherwise           , use the specified directory as base cache directory
+
+    NOTE: you shouldn't use this attribute in HPI modules directly, use Config.get_cache_dir()/cachew.cache_dir() instead
+    '''
+
+    tmp_dir: Optional[PathIsh] = None
+    '''
+    Path to a temporary directory.
+    This can be used temporarily while extracting zipfiles etc...
+    - if None             , uses default determined by tempfile.gettempdir + 'HPI'
+    - otherwise           , use the specified directory as the base temporary directory
+    '''
 
-    # list of regexes/globs
-    # None means 'rely on disabled_modules'
     enabled_modules : Optional[Sequence[str]] = None
+    '''
+    list of regexes/globs
+    - None means 'rely on disabled_modules'
+    '''
 
-    # list of regexes/globs
-    # None means 'rely on enabled_modules'
     disabled_modules: Optional[Sequence[str]] = None
+    '''
+    list of regexes/globs
+    - None means 'rely on enabled_modules'
+    '''
 
+    def get_cache_dir(self) -> Optional[Path]:
+        cdir = self.cache_dir
+        if cdir is None:
+            return None
+        if cdir == _HPI_CACHE_DIR_DEFAULT:
+            from .cachew import _appdirs_cache_dir
+            return _appdirs_cache_dir()
+        else:
+            return Path(cdir).expanduser()
+
+    def get_tmp_dir(self) -> Path:
+        tdir: Optional[PathIsh] = self.tmp_dir
+        tpath: Path
+        # use tempfile if unset
+        if tdir is None:
+            import tempfile
+            tpath = Path(tempfile.gettempdir()) / 'HPI'
+        else:
+            tpath = Path(tdir)
+        tpath = tpath.expanduser()
+        tpath.mkdir(parents=True, exist_ok=True)
+        return tpath
 
     def _is_module_active(self, module: str) -> Optional[bool]:
         # None means the config doesn't specify anything
@@ -72,7 +120,7 @@ config = make_config(Config)
 
 
 ### tests start
-from typing import Iterator, Any
+from typing import Iterator
 from contextlib import contextmanager as ctx
 @ctx
 def _reset_config() -> Iterator[Config]:
@@ -81,6 +129,7 @@ def _reset_config() -> Iterator[Config]:
     with override_config(config) as cc:
         cc.enabled_modules  = None
         cc.disabled_modules = None
+        cc.cache_dir        = None
         yield cc
 
 
