@@ -20,7 +20,7 @@ def get_stats(module: str) -> Optional[StatsFun]:
     # todo detect via ast?
     try:
         mod = import_module(module)
-    except Exception as e:
+    except Exception:
         return None
 
     return getattr(mod, 'stats', None)
@@ -229,9 +229,9 @@ def test_bad_modules(tmp_path: Path) -> None:
 
     (par / 'malicious.py').write_text(f'''
 from pathlib import Path
-Path('{xx}').write_text('aaand your data is gone!')
+Path(r'{xx}').write_text('aaand your data is gone!')
 
-raise RuntimeError("FAIL ON IMPORT! naughy.")
+raise RuntimeError("FAIL ON IMPORT! naughty.")
 
 def stats():
     return [1, 2, 3]
